@@ -1,4 +1,4 @@
-from bionetgen.modelapi.utils import run_command
+from bionetgen.utils.utils import run_command
 import cement
 import subprocess, os
 import bionetgen as bng
@@ -158,7 +158,7 @@ class BNGBase(cement.Controller):
             (
                 ["-op", "--open"],
                 {
-                    "help": "(optional) If given, the notebook will by opened using nbopen",
+                    "help": "(optional) If given, the notebook will be opened using nbopen",
                     "action": "store_true",
                 },
             ),
